@@ -38,11 +38,13 @@ LockScreen::LockScreen()
 
     m_View = new QGraphicsView(&m_Scene);
     m_View->setWindowFlags(Qt::Dialog);
-    m_View->setRenderHint(QPainter::Antialiasing);
+    m_View->setRenderHint(QPainter::Antialiasing, LockScreen::Settings->value("Main/Antialiasing", 1).toInt() == 1);
     m_View->setCacheMode(QGraphicsView::CacheBackground);
     m_View->setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     m_View->setFrameStyle(QFrame::NoFrame);
     m_View->setContentsMargins(0,0,0,0);
+    m_View->setOptimizationFlag(QGraphicsView::DontSavePainterState, true);
+    m_View->setAttribute(Qt::WA_TranslucentBackground, false);
 
     m_WasPortrait = LsWidget::isPortrait();
     m_isDialogActive = false;
@@ -115,13 +117,13 @@ LockScreen::LockScreen()
 
     setHildonFlags();
 
-    if (LockScreen::Debug){
+    /*if (LockScreen::Debug){
         QFontDatabase fDb;
         qDebug() << "Font families available:";
         foreach (QString family, fDb.families()){
             qDebug() << " " << family;
         }
-    }
+    }*/
 }
 
 void LockScreen::setHildonFlags()
@@ -204,8 +206,6 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsMediaTimeLabel(name, m_Player);
     else if (type == "Image")
         return new LsImage(name);
-    else if (type == "CommandButton")
-        return new LsCommandButton(name);
     else if (type == "Notification")
         return new LsNotification(name);
     else if (type == "Text")
