@@ -56,6 +56,7 @@ void printUsage()
 
 int main(int argc, char *argv[])
 {
+    //QApplication::setGraphicsSystem("raster");
     QApplication a(argc, argv);
     a.setOrganizationName("sakya");
     a.setApplicationName("QtLockscreen");
@@ -114,16 +115,16 @@ int main(int argc, char *argv[])
     qDebug() << "sakya_tg@yahoo.it";
 
     //Translation:
-    QString locale = LockScreen::Settings->value("Main/Locale", "").toString();
-    if (!locale.isEmpty()){
-        qDebug() << "Locale override:" << locale;
-        QLocale l(locale);
-        QLocale::setDefault(l);
+    QString localeStr = LockScreen::Settings->value("Main/Locale", "").toString();
+    if (!localeStr.isEmpty()){
+        qDebug() << "Locale override:" << localeStr;
+        QLocale l(localeStr);
+        QLocale::setDefault(l);        
     }else
-        locale = QLocale::system().name();
-    qDebug() << "Locale:" << locale;
+        localeStr = QLocale::system().name();
+    qDebug() << "Locale:" << localeStr;
     QTranslator translator;
-    if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(locale)))
+    if (translator.load(QString("/opt/qtlockscreen/qtlockscreen_%1").arg(localeStr)))
         a.installTranslator(&translator);
 
     LockScreen l;
