@@ -29,7 +29,7 @@ LsDateTime::LsDateTime(QString name):
 
 void LsDateTime::applySettings()
 {
-    m_Alignment = getAlignmentSetting("Alignment", Qt::AlignHCenter);
+    m_Alignment = getAlignmentSetting("Alignment", Qt::AlignHCenter, Qt::AlignTop);
     QDateTime now = QDateTime::currentDateTime();
 
     m_TimeColor = getColorSetting("TimeColor", QColor(255,255,255));
@@ -45,13 +45,13 @@ void LsDateTime::applySettings()
     m_TimeFont = getFontSetting("TimeFont", QFont("", 30, QFont::Normal, false));
 
     QFontMetrics fm(m_TimeFont);
-    QSize size = fm.size(Qt::TextSingleLine, now.toString(m_TimeFormat));
+    QSize size = fm.size(Qt::TextSingleLine, QLocale().toString(now, m_TimeFormat));
 
     QRectF defSize(0,0, size.width(), size.height() + MINIMUM_TEXT_MARGIN);
 
     m_DateFont = getFontSetting("DateFont", QFont("", 12, QFont::Normal, false));
     fm = QFontMetrics(m_DateFont);
-    size = fm.size(Qt::TextSingleLine, now.toString(m_DateFormat));
+    size = fm.size(Qt::TextSingleLine, QLocale().toString(now, m_DateFormat));
     defSize.setHeight(defSize.height() + size.height());
     if (size.width() > defSize.width())
         defSize.setWidth(size.width());
@@ -59,20 +59,21 @@ void LsDateTime::applySettings()
     setSizeAndPosition(QSize(defSize.width(), defSize.height()), QPoint(0, 0));
 }
 
-void LsDateTime::paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *)
+void LsDateTime::paint(QPainter *painter, const QStyleOptionGraphicsItem* option, QWidget *)
 {
+    painter->setClipRect(option->exposedRect);
     QDateTime now = QDateTime::currentDateTime();
 
     painter->setFont(m_TimeFont);
     painter->setPen(m_TimeColor);
-    painter->drawText(boundingRect(), Qt::AlignTop | m_Alignment | Qt::TextSingleLine, now.toString(m_TimeFormat));
+    painter->drawText(boundingRect(), m_Alignment | Qt::TextSingleLine, QLocale().toString(now, m_TimeFormat));
 
     painter->setFont(m_DateFont);
     painter->setPen(m_DateColor);
     QRectF dateRect(boundingRect());
     QFontMetrics fm(m_TimeFont);
-    dateRect.setTop(dateRect.top() + fm.size(Qt::TextSingleLine, now.toString(m_DateFormat)).height() + MINIMUM_TEXT_MARGIN);
-    painter->drawText(dateRect, Qt::AlignTop | m_Alignment | Qt::TextSingleLine, now.toString(m_DateFormat));
+    dateRect.setTop(dateRect.top() + fm.size(Qt::TextSingleLine, QLocale().toString(now, m_DateFormat)).height() + MINIMUM_TEXT_MARGIN);
+    painter->drawText(dateRect, m_Alignment | Qt::TextSingleLine, QLocale().toString(now, m_DateFormat));
 }
 
 void LsDateTime::timerSlot()
