@@ -29,9 +29,10 @@ LsMediaTimeLabel::LsMediaTimeLabel(QString name, SystemPlayer* player) :
     applySettings();
 }
 
-void LsMediaTimeLabel::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
+void LsMediaTimeLabel::paint(QPainter *painter, const QStyleOptionGraphicsItem* option,
                             QWidget*)
 {
+    painter->setClipRect(option->exposedRect);
     QTime t(0,0,0);
     t = t.addSecs(m_Position);
 
