@@ -26,6 +26,7 @@ LsWidget::LsWidget(QString name)
 {
     m_Name = name;
 
+    setFlag(QGraphicsItem::ItemUsesExtendedStyleOption, true);
     setFlag(QGraphicsItem::ItemIsMovable, false);
     setFlag(QGraphicsItem::ItemIsSelectable, false);
     setFlag(QGraphicsItem::ItemIsFocusable, false);
@@ -103,23 +104,39 @@ QColor LsWidget::getColorSetting(QString name, QColor defaultValue)
     return defaultValue;
 }
 
-Qt::AlignmentFlag LsWidget::getAlignmentSetting(QString name, Qt::AlignmentFlag defaultValue)
+int LsWidget::getAlignmentSetting(QString name, Qt::AlignmentFlag defaultHValue, Qt::AlignmentFlag defaultVValue)
 {
+    int result = 0;
     QString align = getSetting(name, "").toString();
-    align = align.toLower().trimmed();
+    QStringList aligns = align.toLower().trimmed().split(";", QString::SkipEmptyParts);
 
-    if (align == "center")
-        return Qt::AlignHCenter;
-    else if (align == "left")
-        return Qt::AlignLeft;
-    else if (align == "right")
-        return Qt::AlignRight;
-    else if (align == "top")
-        return Qt::AlignTop;
-    else if (align == "bottom")
-        return Qt::AlignBottom;
+    if (aligns.count() > 0){
+        align = aligns.at(0);
+        if (align == "center")
+            result |= Qt::AlignHCenter;
+        else if (align == "left")
+            result |= Qt::AlignLeft;
+        else if (align == "right")
+            result |= Qt::AlignRight;
+        else
+            result |= defaultHValue;
+    }else
+        result |= defaultHValue;
 
-    return defaultValue;
+    if (aligns.count() > 1){
+        align = aligns.at(1);
+        if (align == "center")
+            result |= Qt::AlignVCenter;
+        else if (align == "top")
+            result |= Qt::AlignTop;
+        else if (align == "bottom")
+            result |= Qt::AlignBottom;
+        else
+            result |= defaultVValue;
+    }else
+        result |= defaultVValue;
+
+    return result;
 }
 
 QFont LsWidget::getFontSetting(QString name, QFont defaultValue)
