@@ -72,7 +72,7 @@ protected:
     QSize getSizeSetting(QSize defaultValue);
     QSize getSizeSetting(QString name, QSize defaultValue);
     QColor getColorSetting(QString name, QColor defaultValue);
-    Qt::AlignmentFlag getAlignmentSetting(QString name, Qt::AlignmentFlag defaultValue);
+    int getAlignmentSetting(QString name, Qt::AlignmentFlag defaultHValue, Qt::AlignmentFlag defaultVValue);
     QFont getFontSetting(QString name, QFont defaultValue);
 
     void setSize(QSize);
