@@ -34,9 +34,10 @@ LsWifi::LsWifi(QString name) :
 #endif
 }
 
-void LsWifi::paint(QPainter *painter, const QStyleOptionGraphicsItem *,
+void LsWifi::paint(QPainter *painter, const QStyleOptionGraphicsItem* option,
                    QWidget *)
 {
+    painter->setClipRect(option->exposedRect);
     if (m_Connected && !m_Image.isNull()){
         painter->drawPixmap(0,0,m_Image);
     }
